"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Copyright 2017 Google Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
const path = __importStar(require("path"));
const tslint_1 = require("tslint");
/**
 * Run tslint with the default configuration. Returns true on success.
 * @param options gts options
 * @param files files to run linter on
 * @param fix automatically fix linter errors
 */
function lint(options, files = [], fix = false) {
    const tslintConfigPath = path.join(options.gtsRootDir, 'tslint.json');
    const program = createProgram(options);
    const configuration = tslint_1.Configuration.findConfiguration(tslintConfigPath, '').results;
    const linter = new tslint_1.Linter({ fix, formatter: 'codeFrame' }, program);
    const srcFiles = files.length > 0 ? files : tslint_1.Linter.getFileNames(program);
    srcFiles.forEach(file => {
        const sourceFile = program.getSourceFile(file);
        if (sourceFile) {
            const fileContents = sourceFile.getFullText();
            linter.lint(file, fileContents, configuration);
        }
    });
    const result = linter.getResult();
    if (result.errorCount || result.warningCount) {
        options.logger.log(result.output);
        return false;
    }
    return true;
}
exports.lint = lint;
function createProgram(options) {
    const tsconfigPath = path.join(options.targetRootDir, 'tsconfig.json');
    return tslint_1.Linter.createProgram(tsconfigPath);
}
exports.createProgram = createProgram;
//# sourceMappingURL=lint.js.map